@@ -27,12 +27,12 @@ class Params(params.Params):
 
 
 class Hyperparams(hyperparams.Hyperparams):
-    n_bins = hyperparams.UniformInt(
+    n_components = hyperparams.UniformInt(
                             lower=5,
                             upper=15,
                             default=10,
-                            semantic_types=['n_bins'],
-                            description='The maximum number of bins used for continuous variables.'
+                            semantic_types=['n_components'],
+                            description='The maximum number of bins used for continuous variables discretization.'
                             )
 
 
@@ -72,7 +72,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         'installation':[{
             'type': 'PIP',
             'package': 'rpi_featureSelection_python_tools',
-	    'version': '2.0.14'
+	    'version': '2.0.15'
         }],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
         'algorithm_types': 'MINIMUM_REDUNDANCY_FEATURE_SELECTION',
@@ -106,7 +106,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
 
-        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs, 'hm_bins': hyperparams['n_bins']})
+        scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs, 'hm_bins': hyperparams['n_components']})
 
         a = rpi_feature_selection_toolbox.initialize()
         index = np.reshape(np.array(a.IPCMBplus()), [-1, ])
